from PyObjCTools.TestSupport import TestCase
import MetricKit


class TestMXSignpost(TestCase):
    def test_functions_macros(self):
        # Functin macros using _MXSignpostEventEmit_guaranteed_args, which
        # is not available on macOS.

        self.assertNotHasAttr(MetricKit, "MXSignpostEventEmit")
        self.assertNotHasAttr(MetricKit, "MXSignpostIntervalBegin")
        self.assertNotHasAttr(MetricKit, "MXSignpostAnimationIntervalBegin")
        self.assertNotHasAttr(MetricKit, "MXSignpostIntervalEnd")



from PyObjCTools.TestSupport import TestCase, min_sdk_level
import MetricKit
import objc


class TestMXMetricManager(TestCase):
    def test_classes(self):
        MetricKit.MXMetricManager

    @min_sdk_level("12.0")
    def test_protocol(self):
        objc.protocolNamed("MXMetricManagerSubscriber")



from PyObjCTools.TestSupport import TestCase
import MetricKit


class TestMXSignpost_Private(TestCase):
    # XXX: Alternatively expose custom bindings for the public part of the API
    def test_constants(self):
        self.assertEqual(MetricKit._METRICS_SIGNPOST_TYPE_TOKEN, b"signpost:metrics")
        self.assertEqual(
            MetricKit._MXSIGNPOST_METRICS_SNAPSHOT_FORMAT,
            b"\n%{public, " + MetricKit._METRICS_SIGNPOST_TYPE_TOKEN + b"}@",
        )

    def test_function_macros(self):
        # These function macros use _MXSignpostMetricsSnapshot() which
        # is not available on macOS, hence these should not be exposed:
        self.assertNotHasAttr(MetricKit, "_MXSignpostEventEmit_guaranteed_args")
        self.assertNotHasAttr(MetricKit, "_MXSignpostIntervalBegin_guaranteed_args")
        self.assertNotHasAttr(
            MetricKit, "_MXSignpostAnimationIntervalBegin_guaranteed_args"
        )
        self.assertNotHasAttr(MetricKit, "_MXSignpostIntervalEnd_guaranteed_args")



# This file is generated by objective.metadata
#
# Last update: Thu Aug  5 09:34:13 2021
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a


else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$$"""
enums = """$$"""
misc.update(
    {
        "_METRICS_SIGNPOST_TYPE_TOKEN": b"signpost:metrics",
        "_MXSIGNPOST_METRICS_SNAPSHOT_FORMAT": b"\n%{public, signpost:metrics}@",
    }
)
functions = {"_MXSignpostMetricsSnapshot": (b"^v",)}
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"MXMetricPayload",
        b"includesMultipleApplicationVersions",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"NSObject",
        b"didReceiveDiagnosticPayloads:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"didReceiveMetricPayloads:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE
